@@ -45,8 +45,10 @@ class Controller(helper.Controller):
     def upload(req, resp):
         """Process file upload and render thank."""
         if not req.environ['REQUEST_METHOD'] == 'POST':
-            raise AssertionError("'POST' != request.method %r" %
-                                 req.environ['REQUEST_METHOD'])
+            raise AssertionError(
+                "'POST' != request.method %r" %
+                req.environ['REQUEST_METHOD'],
+            )
         return "thanks for '%s'" % req.environ['wsgi.input'].read()
 
     def custom_204(req, resp):
@@ -383,6 +385,11 @@ def test_keepalive(test_client, http_server_protocol):
     assert status_line[4:] == 'OK'
     assert actual_resp_body == pov.encode()
     assert header_has_value('Connection', 'Keep-Alive', actual_headers)
+    assert header_has_value(
+        'Keep-Alive',
+        'timeout={}'.format(test_client.server_instance.timeout),
+        actual_headers,
+    )
 
     # Remove the keep-alive header again.
     status_line, actual_headers, actual_resp_body = test_client.get(
@@ -394,6 +401,7 @@ def test_keepalive(test_client, http_server_protocol):
     assert status_line[4:] == 'OK'
     assert actual_resp_body == pov.encode()
     assert not header_exists('Connection', actual_headers)
+    assert not header_exists('Keep-Alive', actual_headers)
 
     test_client.server_instance.protocol = original_server_protocol
 
@@ -420,8 +428,14 @@ def test_keepalive_conn_management(test_client):
         assert actual_resp_body == pov.encode()
         if keepalive:
             assert header_has_value('Connection', 'Keep-Alive', actual_headers)
+            assert header_has_value(
+                'Keep-Alive',
+                'timeout={}'.format(test_client.server_instance.timeout),
+                actual_headers,
+            )
         else:
             assert not header_exists('Connection', actual_headers)
+            assert not header_exists('Keep-Alive', actual_headers)
 
     disconnect_errors = (
         http_client.BadStatusLine,
@@ -805,11 +819,13 @@ def test_No_Message_Body(test_client):
 
 
 @pytest.mark.xfail(
-    reason=unwrap(trim("""
+    reason=unwrap(
+        trim("""
         Headers from earlier request leak into the request
         line for a subsequent request, resulting in 400
         instead of 413. See cherrypy/cheroot#69 for details.
-        """)),
+        """),
+    ),
 )
 def test_Chunked_Encoding(test_client):
     """Test HTTP uploads with chunked transfer-encoding."""
